# hydrogen-pfhx
Chemical engineering model of hydrogen plate-fin heat exchanger

## Installation
pip install hydrogen-pfhx

## Usage
hydrogen-pfhx is used to model the cryogenic plate-fin heat exchanger used within hydrogen liquefaction plants.
Two examples are given below:

1. Run with a python IDE (e.g. visual studio)
- see the [test file](hydrogen-pfhx/tree/main/tests/test_model.py)

2. A notebook using google colab 
- see the [test notebook](hydrogen-pfhx/tree/main/tests/test_model.ipynb)
- open [colab](https://colab.research.google.com/) and select new notebook
- Copy & paste contents of the [test notebook](hydrogen-pfhx/tree/main/tests/test_model.ipynb) to colab, then "File > Save a copy in drive" to the default location in drive (MyDrive/Colab Notebooks/)
- also save the [default configuration file](hydrogen-pfhx/tree/main/configs/default_configuration.yaml) to the same default drive location
- open the notebook in colab and run
